package com.jiuqi.db;

import java.sql.CallableStatement;
import java.sql.Connection;
import java.sql.DatabaseMetaData;
import java.sql.PreparedStatement;
import java.sql.SQLException;
import java.sql.SQLWarning;
import java.sql.Savepoint;
import java.sql.Statement;
import java.util.Map;

/* loaded from: com_jiuqi_db.jar:com/jiuqi/db/DBConnection.class */
public class DBConnection implements Connection {
    private Connection conn;
    private boolean isTransManaged;

    public DBConnection(IConnection aConn) {
        this.isTransManaged = false;
        this.isTransManaged = false;
        this.conn = aConn.getConnection();
        DBTrace.createConnection(this);
    }

    public DBConnection(Connection aConn) {
        this.isTransManaged = false;
        this.isTransManaged = false;
        this.conn = aConn;
        DBTrace.createConnection(this);
    }

    public DBConnection(IConnection aConn, boolean transManaged, boolean autoCommit) throws SQLException {
        this.isTransManaged = false;
        this.isTransManaged = transManaged;
        this.conn = aConn.getConnection();
        this.conn.setAutoCommit(autoCommit);
        DBTrace.createConnection(this);
    }

    public DBConnection(Connection aConn, boolean transManaged, boolean autoCommit) throws SQLException {
        this.isTransManaged = false;
        this.isTransManaged = transManaged;
        this.conn = aConn;
        this.conn.setAutoCommit(autoCommit);
        DBTrace.createConnection(this);
    }

    @Override // java.sql.Connection
    public Statement createStatement() throws SQLException {
        Statement stmt = this.conn.createStatement();
        return new DBStatement(stmt, this);
    }

    @Override // java.sql.Connection
    public PreparedStatement prepareStatement(String string) throws SQLException {
        PreparedStatement stmt = this.conn.prepareStatement(string);
        return new DBPreparedStatement(stmt, this);
    }

    @Override // java.sql.Connection
    public CallableStatement prepareCall(String string) throws SQLException {
        return this.conn.prepareCall(string);
    }

    @Override // java.sql.Connection
    public String nativeSQL(String string) throws SQLException {
        return this.conn.nativeSQL(string);
    }

    @Override // java.sql.Connection
    public void setAutoCommit(boolean boolean0) throws SQLException {
        if (this.isTransManaged) {
            return;
        }
        this.conn.setAutoCommit(boolean0);
    }

    @Override // java.sql.Connection
    public boolean getAutoCommit() throws SQLException {
        return this.conn.getAutoCommit();
    }

    @Override // java.sql.Connection
    public void commit() throws SQLException {
        if (this.isTransManaged) {
            return;
        }
        this.conn.commit();
    }

    @Override // java.sql.Connection
    public void rollback() throws SQLException {
        if (this.isTransManaged) {
            return;
        }
        this.conn.rollback();
    }

    @Override // java.sql.Connection, java.lang.AutoCloseable
    public void close() throws SQLException {
        DBTrace.closeConnection(this);
        if (this.isTransManaged) {
            return;
        }
        this.conn.close();
    }

    @Override // java.sql.Connection
    public boolean isClosed() throws SQLException {
        return this.conn.isClosed();
    }

    @Override // java.sql.Connection
    public DatabaseMetaData getMetaData() throws SQLException {
        return this.conn.getMetaData();
    }

    @Override // java.sql.Connection
    public void setReadOnly(boolean boolean0) throws SQLException {
        this.conn.setReadOnly(boolean0);
    }

    @Override // java.sql.Connection
    public boolean isReadOnly() throws SQLException {
        return this.conn.isReadOnly();
    }

    @Override // java.sql.Connection
    public void setCatalog(String string) throws SQLException {
        this.conn.setCatalog(string);
    }

    @Override // java.sql.Connection
    public String getCatalog() throws SQLException {
        return this.conn.getCatalog();
    }

    @Override // java.sql.Connection
    public void setTransactionIsolation(int int0) throws SQLException {
        this.conn.setTransactionIsolation(int0);
    }

    @Override // java.sql.Connection
    public int getTransactionIsolation() throws SQLException {
        return this.conn.getTransactionIsolation();
    }

    @Override // java.sql.Connection
    public SQLWarning getWarnings() throws SQLException {
        return this.conn.getWarnings();
    }

    @Override // java.sql.Connection
    public void clearWarnings() throws SQLException {
        this.conn.clearWarnings();
    }

    @Override // java.sql.Connection
    public Statement createStatement(int int0, int int1) throws SQLException {
        Statement stmt = this.conn.createStatement(int0, int1);
        return new DBStatement(stmt, this.conn);
    }

    @Override // java.sql.Connection
    public PreparedStatement prepareStatement(String string, int int1, int int2) throws SQLException {
        PreparedStatement stmt = this.conn.prepareStatement(string, int1, int2);
        return new DBPreparedStatement(stmt, this);
    }

    @Override // java.sql.Connection
    public CallableStatement prepareCall(String string, int int1, int int2) throws SQLException {
        return this.conn.prepareCall(string, int1, int2);
    }

    @Override // java.sql.Connection
    public Map getTypeMap() throws SQLException {
        return this.conn.getTypeMap();
    }

    @Override // java.sql.Connection
    public void setTypeMap(Map map) throws SQLException {
        this.conn.setTypeMap(map);
    }

    @Override // java.sql.Connection
    public void setHoldability(int holdability) throws SQLException {
        this.conn.setHoldability(holdability);
    }

    @Override // java.sql.Connection
    public int getHoldability() throws SQLException {
        return this.conn.getHoldability();
    }

    @Override // java.sql.Connection
    public Savepoint setSavepoint() throws SQLException {
        return this.conn.setSavepoint();
    }

    @Override // java.sql.Connection
    public Savepoint setSavepoint(String name) throws SQLException {
        return this.conn.setSavepoint(name);
    }

    @Override // java.sql.Connection
    public void rollback(Savepoint savepoint) throws SQLException {
        this.conn.rollback(savepoint);
    }

    @Override // java.sql.Connection
    public void releaseSavepoint(Savepoint savepoint) throws SQLException {
        this.conn.releaseSavepoint(savepoint);
    }

    @Override // java.sql.Connection
    public Statement createStatement(int resultSetType, int resultSetConcurrency, int resultSetHoldability) throws SQLException {
        Statement stmt = this.conn.createStatement(resultSetType, resultSetConcurrency);
        return new DBStatement(stmt, this);
    }

    @Override // java.sql.Connection
    public PreparedStatement prepareStatement(String sql, int resultSetType, int resultSetConcurrency, int resultSetHoldability) throws SQLException {
        PreparedStatement stmt = this.conn.prepareStatement(sql, resultSetType, resultSetConcurrency, resultSetHoldability);
        return new DBPreparedStatement(stmt, this);
    }

    @Override // java.sql.Connection
    public CallableStatement prepareCall(String sql, int resultSetType, int resultSetConcurrency, int resultSetHoldability) throws SQLException {
        return this.conn.prepareCall(sql, resultSetType, resultSetConcurrency, resultSetHoldability);
    }

    @Override // java.sql.Connection
    public PreparedStatement prepareStatement(String sql, int autoGeneratedKeys) throws SQLException {
        PreparedStatement stmt = this.conn.prepareStatement(sql, autoGeneratedKeys);
        return new DBPreparedStatement(stmt, this);
    }

    @Override // java.sql.Connection
    public PreparedStatement prepareStatement(String sql, int[] columnIndexes) throws SQLException {
        PreparedStatement stmt = this.conn.prepareStatement(sql, columnIndexes);
        return new DBPreparedStatement(stmt, this);
    }

    @Override // java.sql.Connection
    public PreparedStatement prepareStatement(String sql, String[] columnNames) throws SQLException {
        PreparedStatement stmt = this.conn.prepareStatement(sql, columnNames);
        return new DBPreparedStatement(stmt, this);
    }
}
